summaryrefslogtreecommitdiffstats
path: root/kstyles
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:57:02 -0600
committerSlávek Banko <slavek.banko@axis.cz>2012-06-02 19:04:59 +0200
commit41b1d53a0144afe4c31425c18af25c2d6ade881b (patch)
tree4bf4a434c5db64325f317e56cc9d8d2a729df3e4 /kstyles
parente2867c1f1eec514d56386f2fc5350eaaf760532a (diff)
downloadtdelibs-41b1d53a0144afe4c31425c18af25c2d6ade881b.tar.gz
tdelibs-41b1d53a0144afe4c31425c18af25c2d6ade881b.zip
Remove additional unneeded tq method conversions
(cherry picked from commit a51cd9949c4e6c726a84a61de3cfadd30cefb5c7)
Diffstat (limited to 'kstyles')
-rw-r--r--kstyles/asteroid/asteroid.cpp34
-rw-r--r--kstyles/highcolor/highcolor.cpp6
-rw-r--r--kstyles/highcontrast/highcontrast.cpp14
-rw-r--r--kstyles/keramik/keramik.cpp18
-rw-r--r--kstyles/klegacy/klegacystyle.cpp16
-rw-r--r--kstyles/kthemestyle/kthemebase.cpp2
-rw-r--r--kstyles/kthemestyle/kthemestyle.cpp10
-rw-r--r--kstyles/kthemestyle/kthemestyle.h2
-rw-r--r--kstyles/light/lightstyle-v2.cpp2
-rw-r--r--kstyles/light/lightstyle-v3.cpp4
-rw-r--r--kstyles/plastik/plastik.cpp42
-rw-r--r--kstyles/web/webstyle.cpp8
12 files changed, 79 insertions, 79 deletions
diff --git a/kstyles/asteroid/asteroid.cpp b/kstyles/asteroid/asteroid.cpp
index ad01300c3..3a23b25ac 100644
--- a/kstyles/asteroid/asteroid.cpp
+++ b/kstyles/asteroid/asteroid.cpp
@@ -977,7 +977,7 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
bool lastTab = (tb->indexOf( t->identifier() ) == tb->count()-1) ?
TRUE : FALSE;
TQRect r2( r );
- if ( tb->tqshape() == TQTabBar::RoundedAbove ) {
+ if ( tb->shape() == TQTabBar::RoundedAbove ) {
p->setPen( cg.light() );
p->drawLine( r2.left(), r2.bottom()-1, r2.right(), r2.bottom()-1 );
if ( r2.left() == 0 )
@@ -1015,7 +1015,7 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
x2++;
p->drawLine( x2, r2.top() + 2, x2, r2.bottom() -
(selected ? (lastTab ? 0:1) :2));
- } else if ( tb->tqshape() == TQTabBar::RoundedBelow ) {
+ } else if ( tb->shape() == TQTabBar::RoundedBelow ) {
bool rightAligned = styleHint( SH_TabBar_Alignment, tb ) == TQt::AlignRight;
bool firstTab = tb->indexOf( t->identifier() ) == 0;
if ( selected ) {
@@ -1081,9 +1081,9 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
tr.setBottom( tr.bottom() -
pixelMetric( TQStyle::PM_DefaultFrameWidth, tb ) );
- int tqalignment = TQt::AlignCenter | TQt::ShowPrefix;
+ int alignment = TQt::AlignCenter | TQt::ShowPrefix;
if (!styleHint(SH_UnderlineAccelerator, w, TQStyleOption::Default, 0))
- tqalignment |= TQt::NoAccel;
+ alignment |= TQt::NoAccel;
tr.setWidth(tr.width()+4); // Compensate for text appearing too far to the left
// TQRect tr_offset = TQRect(tr.x()+ETCH_X_OFFSET, tr.y()+ETCH_Y_OFFSET, tr.width(), tr.height());
TQRect tr_offset = TQRect(tr.x()+0, tr.y()+0, tr.width(), tr.height());
@@ -1098,7 +1098,7 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
etchedcg.setColor( TQColorGroup::HighlightedText, cg.light() );
etchedcg.setColor( TQColorGroup::BrightText, cg.light() );
etchedcg.setColor( TQColorGroup::ButtonText, cg.light() );
- drawItem( p, tr_offset, tqalignment, etchedcg, enabled, 0, t->text() );
+ drawItem( p, tr_offset, alignment, etchedcg, enabled, 0, t->text() );
p->setPen( cg.dark() );
etchedcg.setColor( TQColorGroup::Text, cg.dark() );
etchedcg.setColor( TQColorGroup::Mid, cg.dark() );
@@ -1107,11 +1107,11 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
etchedcg.setColor( TQColorGroup::HighlightedText, cg.dark() );
etchedcg.setColor( TQColorGroup::BrightText, cg.dark() );
etchedcg.setColor( TQColorGroup::ButtonText, cg.dark() );
- drawItem( p, tr, tqalignment, etchedcg, enabled, 0, t->text() );
+ drawItem( p, tr, alignment, etchedcg, enabled, 0, t->text() );
p->setPen(savePen);
}
else {
- drawItem( p, tr, tqalignment, cg, enabled, 0, t->text() );
+ drawItem( p, tr, alignment, cg, enabled, 0, t->text() );
}
if ( (sf & Style_HasFocus) && !t->text().isEmpty() )
@@ -1128,9 +1128,9 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
const bool enabled = sf & Style_Enabled;
bool etchtext = styleHint( SH_EtchDisabledText );
- int tqalignment = TQApplication::reverseLayout() ? TQt::AlignRight : TQt::AlignLeft;
+ int alignment = TQApplication::reverseLayout() ? TQt::AlignRight : TQt::AlignLeft;
if (!styleHint(SH_UnderlineAccelerator, w, TQStyleOption::Default, 0))
- tqalignment |= TQt::NoAccel;
+ alignment |= TQt::NoAccel;
//TQRect r_offset = TQRect(r.x()+ETCH_X_OFFSET, r.y()+ETCH_Y_OFFSET, r.width(), r.height());
TQRect r_offset = TQRect(r.x()+0, r.y()+0, r.width(), r.height());
@@ -1145,7 +1145,7 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
etchedcg.setColor( TQColorGroup::HighlightedText, cg.light() );
etchedcg.setColor( TQColorGroup::BrightText, cg.light() );
etchedcg.setColor( TQColorGroup::ButtonText, cg.light() );
- drawItem(p, r_offset, tqalignment | TQt::AlignVCenter | TQt::ShowPrefix, etchedcg, sf & Style_Enabled, checkbox->pixmap(), checkbox->text());
+ drawItem(p, r_offset, alignment | TQt::AlignVCenter | TQt::ShowPrefix, etchedcg, sf & Style_Enabled, checkbox->pixmap(), checkbox->text());
p->setPen( cg.dark() );
etchedcg.setColor( TQColorGroup::Text, cg.dark() );
etchedcg.setColor( TQColorGroup::Mid, cg.dark() );
@@ -1154,11 +1154,11 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
etchedcg.setColor( TQColorGroup::HighlightedText, cg.dark() );
etchedcg.setColor( TQColorGroup::BrightText, cg.dark() );
etchedcg.setColor( TQColorGroup::ButtonText, cg.dark() );
- drawItem(p, r, tqalignment | TQt::AlignVCenter | TQt::ShowPrefix, etchedcg, sf & Style_Enabled, checkbox->pixmap(), checkbox->text());
+ drawItem(p, r, alignment | TQt::AlignVCenter | TQt::ShowPrefix, etchedcg, sf & Style_Enabled, checkbox->pixmap(), checkbox->text());
p->setPen(savePen);
}
else {
- drawItem(p, r, tqalignment | TQt::AlignVCenter | TQt::ShowPrefix, cg, sf & Style_Enabled, checkbox->pixmap(), checkbox->text());
+ drawItem(p, r, alignment | TQt::AlignVCenter | TQt::ShowPrefix, cg, sf & Style_Enabled, checkbox->pixmap(), checkbox->text());
}
if (sf & Style_HasFocus) {
@@ -1177,9 +1177,9 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
const bool enabled = sf & Style_Enabled;
bool etchtext = styleHint( SH_EtchDisabledText );
- int tqalignment = TQApplication::reverseLayout() ? TQt::AlignRight : TQt::AlignLeft;
+ int alignment = TQApplication::reverseLayout() ? TQt::AlignRight : TQt::AlignLeft;
if (!styleHint(SH_UnderlineAccelerator, w, TQStyleOption::Default, 0))
- tqalignment |= TQt::NoAccel;
+ alignment |= TQt::NoAccel;
// TQRect r_offset = TQRect(r.x()+ETCH_X_OFFSET, r.y()+ETCH_Y_OFFSET, r.width(), r.height());
TQRect r_offset = TQRect(r.x()+0, r.y()+0, r.width(), r.height());
@@ -1194,7 +1194,7 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
etchedcg.setColor( TQColorGroup::HighlightedText, cg.light() );
etchedcg.setColor( TQColorGroup::BrightText, cg.light() );
etchedcg.setColor( TQColorGroup::ButtonText, cg.light() );
- drawItem(p, r_offset, tqalignment | TQt::AlignVCenter | TQt::ShowPrefix, etchedcg, enabled, radiobutton->pixmap(), radiobutton->text());
+ drawItem(p, r_offset, alignment | TQt::AlignVCenter | TQt::ShowPrefix, etchedcg, enabled, radiobutton->pixmap(), radiobutton->text());
p->setPen( cg.dark() );
etchedcg.setColor( TQColorGroup::Text, cg.dark() );
etchedcg.setColor( TQColorGroup::Mid, cg.dark() );
@@ -1203,10 +1203,10 @@ void AsteroidStyle::drawControl(TQ_ControlElement ce,
etchedcg.setColor( TQColorGroup::HighlightedText, cg.dark() );
etchedcg.setColor( TQColorGroup::BrightText, cg.dark() );
etchedcg.setColor( TQColorGroup::ButtonText, cg.dark() );
- drawItem(p, r, tqalignment | TQt::AlignVCenter | TQt::ShowPrefix, etchedcg, enabled, radiobutton->pixmap(), radiobutton->text());
+ drawItem(p, r, alignment | TQt::AlignVCenter | TQt::ShowPrefix, etchedcg, enabled, radiobutton->pixmap(), radiobutton->text());
p->setPen(savePen);
}
- drawItem(p, r, tqalignment | TQt::AlignVCenter | TQt::ShowPrefix, cg, enabled, radiobutton->pixmap(), radiobutton->text());
+ drawItem(p, r, alignment | TQt::AlignVCenter | TQt::ShowPrefix, cg, enabled, radiobutton->pixmap(), radiobutton->text());
if (sf & Style_HasFocus) {
TQRect fr = visualRect(subRect(SR_RadioButtonFocusRect, w), w);
diff --git a/kstyles/highcolor/highcolor.cpp b/kstyles/highcolor/highcolor.cpp
index a1eb876fc..b2ab9e493 100644
--- a/kstyles/highcolor/highcolor.cpp
+++ b/kstyles/highcolor/highcolor.cpp
@@ -1926,7 +1926,7 @@ TQSize HighColorStyle::tqsizeFromContents( ContentsType contents,
}
-// Fix Qt's wacky image tqalignment
+// Fix Qt's wacky image alignment
TQPixmap HighColorStyle::stylePixmap(StylePixmap stylepixmap,
const TQWidget* widget,
const TQStyleOption& opt) const
@@ -1958,12 +1958,12 @@ bool HighColorStyle::eventFilter( TQObject *object, TQEvent *event )
if ( (event->type() == TQEvent::Enter) &&
(button->isEnabled()) ) {
hoverWidget = button;
- button->tqrepaint( false );
+ button->repaint( false );
}
else if ( (event->type() == TQEvent::Leave) &&
(TQT_BASE_OBJECT(object) == TQT_BASE_OBJECT(hoverWidget)) ) {
hoverWidget = 0L;
- button->tqrepaint( false );
+ button->repaint( false );
}
} else if ( object->parent() && !qstrcmp( object->name(), kdeToolbarWidget ) )
{
diff --git a/kstyles/highcontrast/highcontrast.cpp b/kstyles/highcontrast/highcontrast.cpp
index 984465a4e..e6c3be350 100644
--- a/kstyles/highcontrast/highcontrast.cpp
+++ b/kstyles/highcontrast/highcontrast.cpp
@@ -759,9 +759,9 @@ void HighContrastStyle::drawControl (TQ_ControlElement element,
drawRoundRect (p, r);
const TQTabBar *tb = static_cast< const TQTabBar * >(widget);
- TQTabBar::Shape tqshape = tb->tqshape();
- if (tqshape == TQTabBar::TriangularBelow ||
- tqshape == TQTabBar::RoundedBelow) {
+ TQTabBar::Shape shape = tb->shape();
+ if (shape == TQTabBar::TriangularBelow ||
+ shape == TQTabBar::RoundedBelow) {
p->fillRect (r.left(), r.top(),
r.width(), 2*basicLineWidth,
p->pen().color());
@@ -1811,7 +1811,7 @@ bool HighContrastStyle::eventFilter (TQObject *object, TQEvent *event)
|| widget->inherits (TQSPINWIDGET_OBJECT_NAME_STRING)))
{
hoverWidget = widget;
- widget->tqrepaint (false);
+ widget->repaint (false);
}
else if (event->type() == TQEvent::Leave
&& (widget->inherits (TQBUTTON_OBJECT_NAME_STRING)
@@ -1820,7 +1820,7 @@ bool HighContrastStyle::eventFilter (TQObject *object, TQEvent *event)
{
if (TQT_BASE_OBJECT(object) == TQT_BASE_OBJECT(hoverWidget))
hoverWidget = 0L;
- widget->tqrepaint (false);
+ widget->repaint (false);
}
// Make sure the focus rectangle is shown correctly.
else if (event->type() == TQEvent::FocusIn || event->type() == TQEvent::FocusOut)
@@ -1834,9 +1834,9 @@ bool HighContrastStyle::eventFilter (TQObject *object, TQEvent *event)
}
if (widgetparent)
- widgetparent->tqrepaint (false);
+ widgetparent->repaint (false);
else
- widget->tqrepaint (false);
+ widget->repaint (false);
}
}
diff --git a/kstyles/klegacy/klegacystyle.cpp b/kstyles/klegacy/klegacystyle.cpp
index ae9ff1614..e2cc43dce 100644
--- a/kstyles/klegacy/klegacystyle.cpp
+++ b/kstyles/klegacy/klegacystyle.cpp
@@ -2954,8 +2954,8 @@ void KLegacyStyle::drawTab(TQPainter *p, const TQTabBar *tabbar, TQTab *tab, boo
key.data.function = KLegacy::Extension;
key.data.state = (! selected) ? KLegacy::Active : KLegacy::Normal;
key.data.shadow = KLegacy::Out;
- key.data.gapSide = (tabbar->tqshape() == TQTabBar::RoundedAbove ||
- tabbar->tqshape() == TQTabBar::TriangularAbove) ?
+ key.data.gapSide = (tabbar->shape() == TQTabBar::RoundedAbove ||
+ tabbar->shape() == TQTabBar::TriangularAbove) ?
KLegacy::Bottom : KLegacy::Top;
int ry = tab->r.top(), rh = tab->r.height();
@@ -2963,8 +2963,8 @@ void KLegacyStyle::drawTab(TQPainter *p, const TQTabBar *tabbar, TQTab *tab, boo
if (! selected) {
rh -= 2;
- if (tabbar->tqshape() == TQTabBar::RoundedAbove ||
- tabbar->tqshape() == TQTabBar::TriangularAbove)
+ if (tabbar->shape() == TQTabBar::RoundedAbove ||
+ tabbar->shape() == TQTabBar::TriangularAbove)
ry += 2;
}
@@ -3261,7 +3261,7 @@ bool KLegacyStyle::eventFilter(TQObject *obj, TQEvent *e) {
obj->inherits(TQSLIDER_OBJECT_NAME_STRING) ||
obj->inherits(TQSCROLLBAR_OBJECT_NAME_STRING)) {
priv->lastWidget = (TQWidget *) obj;
- priv->lastWidget->tqrepaint(false);
+ priv->lastWidget->repaint(false);
} else if (obj->inherits(TQRADIOBUTTON_OBJECT_NAME_STRING)) {
TQWidget *w = (TQWidget *) obj;
@@ -3327,7 +3327,7 @@ bool KLegacyStyle::eventFilter(TQObject *obj, TQEvent *e) {
{
if (obj == priv->lastWidget) {
priv->lastWidget = 0;
- ((TQWidget *) obj)->tqrepaint(false);
+ ((TQWidget *) obj)->repaint(false);
} else if (obj->inherits(TQRADIOBUTTON_OBJECT_NAME_STRING) ||
obj->inherits(TQCHECKBOX_OBJECT_NAME_STRING)) {
TQWidget *w = (TQWidget *) obj;
@@ -3335,7 +3335,7 @@ bool KLegacyStyle::eventFilter(TQObject *obj, TQEvent *e) {
if (! w->isTopLevel()) {
w->setBackgroundMode(TQWidget::X11ParentRelative);
w->setBackgroundOrigin(TQWidget::WidgetOrigin);
- w->tqrepaint(true);
+ w->repaint(true);
}
}
@@ -3349,7 +3349,7 @@ bool KLegacyStyle::eventFilter(TQObject *obj, TQEvent *e) {
if (obj->inherits(TQSCROLLBAR_OBJECT_NAME_STRING) &&
(! (me->state() & (LeftButton | MidButton | RightButton)))) {
priv->hovering = true;
- ((TQWidget *) obj)->tqrepaint(false);
+ ((TQWidget *) obj)->repaint(false);
priv->hovering = false;
}
diff --git a/kstyles/kthemestyle/kthemebase.cpp b/kstyles/kthemestyle/kthemebase.cpp
index 5096c326c..cb511c198 100644
--- a/kstyles/kthemestyle/kthemebase.cpp
+++ b/kstyles/kthemestyle/kthemebase.cpp
@@ -70,7 +70,7 @@ static TQColor readColorEntry( TQSettings* s, const char *pKey,
TQString aValue = s->readEntry( pKey );
if ( !aValue.isEmpty() )
{
- if ( aValue.tqat( 0 ) == '#' )
+ if ( aValue.at( 0 ) == '#' )
{
aRetColor.setNamedColor( aValue );
}
diff --git a/kstyles/kthemestyle/kthemestyle.cpp b/kstyles/kthemestyle/kthemestyle.cpp
index aaaa05e83..516012b2d 100644
--- a/kstyles/kthemestyle/kthemestyle.cpp
+++ b/kstyles/kthemestyle/kthemestyle.cpp
@@ -650,7 +650,7 @@ void KThemeStyle::drawBaseButton( TQPainter *p, int x, int y, int w, int h,
if ( gradientHint( type ) == GrReverseBevel )
{
int i;
- bitBlt( p->tqdevice(), x, y, TQT_TQPAINTDEVICE(scalePixmap( w, h, type )), 0, 0, w, h,
+ bitBlt( p->device(), x, y, TQT_TQPAINTDEVICE(scalePixmap( w, h, type )), 0, 0, w, h,
TQt::CopyROP, true );
p->setPen( g.text() );
for ( i = 0; i < borderWidth( type ); ++i, ++x, ++y, w -= 2, h -= 2 )
@@ -690,7 +690,7 @@ void KThemeStyle::drawBaseButton( TQPainter *p, int x, int y, int w, int h,
}
if ( borderPixmap( type ) )
{
- bitBlt( p->tqdevice(), x, y, TQT_TQPAINTDEVICE(scaleBorder( w, h, type )), 0, 0, w, h,
+ bitBlt( p->device(), x, y, TQT_TQPAINTDEVICE(scaleBorder( w, h, type )), 0, 0, w, h,
TQt::CopyROP, false );
}
else
@@ -1239,7 +1239,7 @@ void KThemeStyle::drawControl( ControlElement element,
case CE_TabBarTab:
{
const TQTabBar* tb = ( const TQTabBar* ) widget;
- TQTabBar::Shape tbs = tb->tqshape();
+ TQTabBar::Shape tbs = tb->shape();
bool selected = how & Style_Selected;
WidgetType widget = selected ? ActiveTab : InactiveTab;
const TQColorGroup *cg = colorGroup( tb->colorGroup(), widget );
@@ -1315,8 +1315,8 @@ void KThemeStyle::drawControl( ControlElement element,
else
p->fillRect( x, y, x2 - x + 1, y2 - y + 1, cg->background() );
}
- else if ( tb->tqshape() == TQTabBar::RoundedBelow ||
- tb->tqshape() == TQTabBar::TriangularBelow )
+ else if ( tb->shape() == TQTabBar::RoundedBelow ||
+ tb->shape() == TQTabBar::TriangularBelow )
{
if ( widget == ActiveTab )
widget = RotActiveTab;
diff --git a/kstyles/kthemestyle/kthemestyle.h b/kstyles/kthemestyle/kthemestyle.h
index 64261fe92..fccf62c34 100644
--- a/kstyles/kthemestyle/kthemestyle.h
+++ b/kstyles/kthemestyle/kthemestyle.h
@@ -192,7 +192,7 @@ public:
* @param w The rectangle width.
* @param h The rectangle height.
* @param sunken Draws a sunken style if @p true.
- * @param rounded Draws a rounded tqshape if @p true. Requires bWidth to be
+ * @param rounded Draws a rounded shape if @p true. Requires bWidth to be
* at least 1.
* @param hWidth The highlight width.
* @param bWidth The border width.
diff --git a/kstyles/light/lightstyle-v2.cpp b/kstyles/light/lightstyle-v2.cpp
index 3601fbb68..a55e2edad 100644
--- a/kstyles/light/lightstyle-v2.cpp
+++ b/kstyles/light/lightstyle-v2.cpp
@@ -635,7 +635,7 @@ void LightStyleV2::drawControl( TQ_ControlElement control,
tr.addCoords(0, 0, 0, -1);
fr.addCoords(2, 2, -2, -2);
- if ( tb->tqshape() == TQTabBar::RoundedBelow || tb->tqshape() == TQTabBar::TriangularBelow) {
+ if ( tb->shape() == TQTabBar::RoundedBelow || tb->shape() == TQTabBar::TriangularBelow) {
tr = r; tr.addCoords(0, 1, 0, 0);
fr = r; fr.addCoords(2, 2,-2, -4);
below = true;
diff --git a/kstyles/light/lightstyle-v3.cpp b/kstyles/light/lightstyle-v3.cpp
index 7b5a8135e..a31dba078 100644
--- a/kstyles/light/lightstyle-v3.cpp
+++ b/kstyles/light/lightstyle-v3.cpp
@@ -818,7 +818,7 @@ void LightStyleV3::drawControl( TQ_ControlElement control,
const TQTabBar *tb = (const TQTabBar *) widget;
TQRect br = r;
- if ( tb->tqshape() == TQTabBar::RoundedAbove ) {
+ if ( tb->shape() == TQTabBar::RoundedAbove ) {
if ( ! ( flags & Style_Selected ) ) {
p->setPen( cg.background() );
p->drawLine( br.left(), br.bottom(),
@@ -853,7 +853,7 @@ void LightStyleV3::drawControl( TQ_ControlElement control,
else
br.addCoords( 1, 1, -1, 0 );
p->fillRect( br, cg.background() );
- } else if ( tb->tqshape() == TQTabBar::RoundedBelow ) {
+ } else if ( tb->shape() == TQTabBar::RoundedBelow ) {
if ( ! ( flags & Style_Selected ) ) {
p->setPen( cg.background() );
p->drawLine( br.left(), br.top(),
diff --git a/kstyles/plastik/plastik.cpp b/kstyles/plastik/plastik.cpp
index 68f717b6a..dfa6fb341 100644
--- a/kstyles/plastik/plastik.cpp
+++ b/kstyles/plastik/plastik.cpp
@@ -885,8 +885,8 @@ void PlastikStyle::renderPanel(TQPainter *p,
r.coords(&x, &y, &x2, &y2);
if (kickerMode &&
- p->tqdevice() && p->tqdevice()->devType() == TQInternal::Widget &&
- TQCString(static_cast<TQWidget*>(static_cast<QWidget*>(static_cast<QPaintDevice*>(p->tqdevice())))->className()) == "FittsLawFrame") {
+ p->device() && p->device()->devType() == TQInternal::Widget &&
+ TQCString(static_cast<TQWidget*>(static_cast<QWidget*>(static_cast<QPaintDevice*>(p->device())))->className()) == "FittsLawFrame") {
// Stolen wholesale from Keramik. I don't like it, but oh well.
if (sunken) {
const TQCOORD corners[] = { x2, y, x2, y2, x, y2, x, y };
@@ -1483,7 +1483,7 @@ void PlastikStyle::tqdrawPrimitive(TQ_PrimitiveElement pe,
if(!kickerMode) {
// detect if this is the left most header item
bool isFirst = false;
- TQHeader *header = dynamic_cast<TQHeader*>(p->tqdevice() );
+ TQHeader *header = dynamic_cast<TQHeader*>(p->device() );
if (header) {
isFirst = header->mapToIndex(header->sectionAt(r.x() ) ) == 0;
}
@@ -1819,7 +1819,7 @@ void PlastikStyle::tqdrawPrimitive(TQ_PrimitiveElement pe,
// --------------
case PE_Splitter: {
// highlight on mouse over
- TQColor color = (static_cast<QPaintDevice*>(static_cast<QWidget*>(hoverWidget)) == static_cast<QPaintDevice*>(p->tqdevice()))?TQColor(cg.background().light(100+_contrast)):cg.background();
+ TQColor color = (static_cast<QPaintDevice*>(static_cast<QWidget*>(hoverWidget)) == static_cast<QPaintDevice*>(p->device()))?TQColor(cg.background().light(100+_contrast)):cg.background();
p->fillRect(r, color);
if (w > h) {
if (h > 4) {
@@ -1862,9 +1862,9 @@ void PlastikStyle::tqdrawPrimitive(TQ_PrimitiveElement pe,
bool isEnabled = true;
// panel is highlighted by default if it has focus, but if we have access to the
// widget itself we can try to avoid highlighting in case it's readOnly or disabled.
- if (p->tqdevice() && dynamic_cast<TQLineEdit*>(p->tqdevice()))
+ if (p->device() && dynamic_cast<TQLineEdit*>(p->device()))
{
- TQLineEdit* lineEdit = dynamic_cast<TQLineEdit*>(p->tqdevice());
+ TQLineEdit* lineEdit = dynamic_cast<TQLineEdit*>(p->device());
isReadOnly = lineEdit->isReadOnly();
isEnabled = lineEdit->isEnabled();
}
@@ -1881,7 +1881,7 @@ void PlastikStyle::tqdrawPrimitive(TQ_PrimitiveElement pe,
// only thing we know is that khtml buffers its widgets into a pixmap. So
// when the paint device is a TQPixmap, chances are high that we are in khtml.
// It's possible that this breaks other things, so let's see how it works...
- if (p->tqdevice() && dynamic_cast<TQPixmap*>(p->tqdevice() ) ) {
+ if (p->device() && dynamic_cast<TQPixmap*>(p->device() ) ) {
contourFlags += Draw_AlphaBlend;
}
@@ -1942,7 +1942,7 @@ void PlastikStyle::tqdrawPrimitive(TQ_PrimitiveElement pe,
case PE_PanelMenuBar:
case PE_PanelDockWindow: {
// fix for toolbar lag (from Mosfet Liquid)
- TQWidget* w = dynamic_cast<TQWidget*>(p->tqdevice());
+ TQWidget* w = dynamic_cast<TQWidget*>(p->device());
if(w && w->backgroundMode() == PaletteButton)
w->setBackgroundMode(PaletteBackground);
p->fillRect(r, cg.brush(TQColorGroup::Background));
@@ -2301,7 +2301,7 @@ void PlastikStyle::drawControl(TQ_ControlElement element,
if(cw)
cornerWidget = true;
}
- TQTabBar::Shape tbs = tb->tqshape();
+ TQTabBar::Shape tbs = tb->shape();
bool selected = false;
if (flags & Style_Selected) selected = true;
TabPosition pos;
@@ -3253,8 +3253,8 @@ int PlastikStyle::pixelMetric(PixelMetric m, const TQWidget *widget) const
// ----
case PM_TabBarTabVSpace: {
const TQTabBar * tb = (const TQTabBar *) widget;
- if (tb->tqshape() == TQTabBar::RoundedAbove ||
- tb->tqshape() == TQTabBar::RoundedBelow)
+ if (tb->shape() == TQTabBar::RoundedAbove ||
+ tb->shape() == TQTabBar::RoundedBelow)
return 12;
else
return 4;
@@ -3464,14 +3464,14 @@ bool PlastikStyle::eventFilter(TQObject *obj, TQEvent *ev)
TQWidget* spinbox = widget->parentWidget();
if ((ev->type() == TQEvent::FocusIn) || (ev->type() == TQEvent::FocusOut))
{
- spinbox->tqrepaint(false);
+ spinbox->repaint(false);
}
return false;
}
if ((ev->type() == TQEvent::FocusIn) || (ev->type() == TQEvent::FocusOut))
{
- widget->tqrepaint(false);
+ widget->repaint(false);
}
return false;
}
@@ -3485,13 +3485,13 @@ bool PlastikStyle::eventFilter(TQObject *obj, TQEvent *ev)
{
TQWidget* button = TQT_TQWIDGET(obj);
hoverWidget = button;
- button->tqrepaint(false);
+ button->repaint(false);
}
else if ((ev->type() == TQEvent::Leave) && (TQT_BASE_OBJECT(obj) == TQT_BASE_OBJECT(hoverWidget)) )
{
TQWidget* button = TQT_TQWIDGET(obj);
hoverWidget = 0;
- button->tqrepaint(false);
+ button->repaint(false);
}
return false;
}
@@ -3501,7 +3501,7 @@ bool PlastikStyle::eventFilter(TQObject *obj, TQEvent *ev)
TQWidget* tabbar = TQT_TQWIDGET(obj);
hoverWidget = tabbar;
hoverTab = 0;
- tabbar->tqrepaint(false);
+ tabbar->repaint(false);
}
else if (ev->type() == TQEvent::MouseMove)
{
@@ -3512,15 +3512,15 @@ bool PlastikStyle::eventFilter(TQObject *obj, TQEvent *ev)
// avoid unnecessary repaints (which otherwise would occour on every
// MouseMove event causing high cpu load).
- bool tqrepaint = true;
+ bool repaint = true;
TQTab *tab = tabbar->selectTab(me->pos() );
if (hoverTab == tab)
- tqrepaint = false;
+ repaint = false;
hoverTab = tab;
- if (tqrepaint)
- tabbar->tqrepaint(false);
+ if (repaint)
+ tabbar->repaint(false);
}
}
else if (ev->type() == TQEvent::Leave)
@@ -3528,7 +3528,7 @@ bool PlastikStyle::eventFilter(TQObject *obj, TQEvent *ev)
TQWidget* tabbar = TQT_TQWIDGET(obj);
hoverWidget = 0;
hoverTab = 0;
- tabbar->tqrepaint(false);
+ tabbar->repaint(false);
}
return false;
}
diff --git a/kstyles/web/webstyle.cpp b/kstyles/web/webstyle.cpp
index b9eff2f7b..ab5282e06 100644
--- a/kstyles/web/webstyle.cpp
+++ b/kstyles/web/webstyle.cpp
@@ -303,12 +303,12 @@ WebStyle::eventFilter(TQObject * o, TQEvent * e)
if (e->type() == TQEvent::Enter)
{
_highlightedButton = pb;
- pb->tqrepaint(false);
+ pb->repaint(false);
}
else if (e->type() == TQEvent::Leave)
{
_highlightedButton = 0;
- pb->tqrepaint(false);
+ pb->repaint(false);
}
return false;
@@ -754,7 +754,7 @@ WebStyle::drawExclusiveIndicator
p->setBrush(g.brush(TQColorGroup::Background));
- // Avoid mistqshapen ellipses. Qt or X bug ? Who knows...
+ // Avoid misshapen ellipses. Qt or X bug ? Who knows...
if (0 == w % 2)
--w;
@@ -1457,7 +1457,7 @@ WebStyle::drawTab
p->setPen(selected ? g.dark() : g.mid());
p->fillRect(r, g.brush(TQColorGroup::Background));
- switch (tabBar->tqshape())
+ switch (tabBar->shape())
{
case TQTabBar::RoundedAbove:
case TQTabBar::TriangularAbove:
diff --git a/kstyles/keramik/keramik.cpp b/kstyles/keramik/keramik.cpp
index 41abc3598..85333299f 100644
--- a/kstyles/keramik/keramik.cpp
+++ b/kstyles/keramik/keramik.cpp
@@ -956,7 +956,7 @@ void KeramikStyle::tqdrawPrimitive( TQ_PrimitiveElement pe,
if (kickerMode)
{
if (p->device() && p->device()->devType() == TQInternal::Widget &&
- TQCString(static_cast<TQWidget*>(static_cast<QWidget*>(static_cast<QPaintDevice*>(p->tqdevice())))->className()) == "FittsLawFrame" )
+ TQCString(static_cast<TQWidget*>(static_cast<QWidget*>(static_cast<QPaintDevice*>(p->device())))->className()) == "FittsLawFrame" )
{
int x2 = x + r.width() - 1;
int y2 = y + r.height() - 1;
@@ -1496,8 +1496,8 @@ void KeramikStyle::drawControl( TQ_ControlElement element,
{
const TQTabBar* tabBar = static_cast< const TQTabBar* >( widget );
- bool bottom = tabBar->tqshape() == TQTabBar::RoundedBelow ||
- tabBar->tqshape() == TQTabBar::TriangularBelow;
+ bool bottom = tabBar->shape() == TQTabBar::RoundedBelow ||
+ tabBar->shape() == TQTabBar::TriangularBelow;
if ( flags & Style_Selected )
{
@@ -1999,7 +1999,7 @@ void KeramikStyle::drawComplexControl( TQ_ComplexControl control,
//but that also alters height and not just width.
//readjust height to fake the other metrics (plus clear
//the other areas, as appropriate). The automasker
//will take care of the overall tqshape.
if ( compact )
{
forceSmallMode = true;
@@ -2397,8 +2397,8 @@ int KeramikStyle::pixelMetric(PixelMetric m, const TQWidget *widget) const
const TQTabBar* tb = ::tqqt_cast<const TQTabBar*>(widget);
if (tb)
{
- if (tb->tqshape() == TQTabBar::RoundedBelow ||
- tb->tqshape() == TQTabBar::TriangularBelow)
+ if (tb->shape() == TQTabBar::RoundedBelow ||
+ tb->shape() == TQTabBar::TriangularBelow)
return 0;
}
@@ -2751,7 +2751,7 @@ bool KeramikStyle::eventFilter( TQObject* object, TQEvent* event )
{
TQWidget* button = TQT_TQWIDGET(object);
hoverWidget = 0;
- button->tqrepaint( false );
+ button->repaint( false );
return false;
}
@@ -2761,7 +2761,7 @@ bool KeramikStyle::eventFilter( TQObject* object, TQEvent* event )
if (event->type() == TQEvent::Enter && TQT_TQWIDGET(object)->isEnabled() )
{
hoverWidget = TQT_TQWIDGET(object);
- hoverWidget->tqrepaint( false );
+ hoverWidget->repaint( false );
}
return false;
}
@@ -2789,7 +2789,7 @@ bool KeramikStyle::eventFilter( TQObject* object, TQEvent* event )
switch (event->type())
{
#ifdef HAVE_X11_EXTENSIONS_SHAPE_H
- //Combo dropdowns are tqshaped
+ //Combo dropdowns are shaped
case TQEvent::Resize:
{
TQListBox* listbox = static_cast<TQListBox*>(TQT_TQWIDGET(object));
@@ -1999,7 +1999,7 @@ void KeramikStyle::drawComplexControl( TQ_ComplexControl control,
//readjust height to fake the other metrics (plus clear
//the other areas, as appropriate). The automasker
- //will take care of the overall tqshape.
+ //will take care of the overall shape.
if ( compact )
{